# Angka

[![Documentation Status](https://readthedocs.org/projects/angka/badge/?version=latest)](https://angka.readthedocs.io/en/latest/?badge=latest)


a repository focusing on data processing package namely angka. 
It focuses on matrix data manipulating and visualization in C.
The project is an initial step for the applied focuses, especially
earth science purposes. We also have a goal to wrap this library to
another language such as Python.

### The important links:

- Documentation: http://angka.readthedocs.io
